==> spongeapi-8.0.0-20210324.005901-379-sources.jar: org/spongepowered/api/entity/explosive/fused/FusedExplosive.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.entity.explosive.fused;

import org.spongepowered.api.data.Keys;
import org.spongepowered.api.data.value.Value;
import org.spongepowered.api.entity.explosive.Explosive;
import org.spongepowered.api.util.Ticks;

/**
 * Represents an explosive that detonates after its fuse has expired.
 * <p>A FusedExplosive may already be ignited once spawned.</p>
 */
public interface FusedExplosive extends Explosive {

    /**
     * {@link Keys#IS_PRIMED}
     * @return True if this explosive is primed
     */
    default Value.Mutable<Boolean> primed() {
        return this.requireValue(Keys.IS_PRIMED).asMutable();
    }

    /**
     * {@link Keys#FUSE_DURATION}
     * @return The fuse duration, if this explosive is primed
     */
    default Value.Mutable<Ticks> fuseDuration() {
        return this.requireValue(Keys.FUSE_DURATION).asMutable();
    }
}

==> spongeapi-8.0.0-20220108.065912-540-sources.jar: org/spongepowered/api/entity/explosive/fused/FusedExplosive.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.entity.explosive.fused;

import org.spongepowered.api.data.Keys;
import org.spongepowered.api.data.value.Value;
import org.spongepowered.api.entity.explosive.Explosive;
import org.spongepowered.api.util.Ticks;

/**
 * Represents an explosive that detonates after its fuse has expired.
 * <p>A FusedExplosive may already be ignited once spawned.</p>
 */
public interface FusedExplosive extends Explosive {

    /**
     * {@link Keys#IS_PRIMED}
     *
     * @return True if this explosive is primed
     */
    default Value.Mutable<Boolean> primed() {
        return this.requireValue(Keys.IS_PRIMED).asMutable();
    }

    /**
     * {@link Keys#FUSE_DURATION}
     *
     * @return The fuse duration, if this explosive is primed
     */
    default Value.Mutable<Ticks> fuseDuration() {
        return this.requireValue(Keys.FUSE_DURATION).asMutable();
    }

    /**
     * {@link Keys#TICKS_REMAINING}
     *
     * @return The remaining fuse time in ticks of the fused explosive
     */
    default Value.Mutable<Ticks> ticksRemaining() {
        return this.requireValue(Keys.TICKS_REMAINING).asMutable();
    }
}
